@@ -22,7 +22,7 @@ function(z, col, units="", SIDE=1, s1=.4, s2=0.95)
 
     if(SIDE==1)
       {
-        ym = ymarginfo(SIDE=1, s1=s1, s2=s2)
+        ym = RPMG::ymarginfo(SIDE=1, s1=s1, s2=s2)
 
         ## y1 = ym[1]
         
@@ -31,7 +31,7 @@ function(z, col, units="", SIDE=1, s1=.4, s2=0.95)
     else
       {
         ## y1 =u[4]+dy*0.2
-        ym = ymarginfo(SIDE=3, s1=s1, s2=s2)
+        ym = RPMG::ymarginfo(SIDE=3, s1=s1, s2=s2)
         
         LU=list(x=c(u[1]+dx*0.1, u[1]+dx*0.1+dx), y = ym)
         
